@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -66,13 +66,13 @@ extern "C"
  * Free a Proxy-Authenticate element.
  * @param header The element to work on.
  */
-#define osip_proxy_authenticate_free(header)     osip_www_authenticate_free(header)
+#define osip_proxy_authenticate_free     osip_www_authenticate_free
 /**
  * Clone a Proxy-Authenticate element.
  * @param header The element to work on.
  * @param dest A pointer on the copy of the element.
  */
-#define osip_proxy_authenticate_clone(header, dest) osip_www_authenticate_clone(header, dest)
+#define osip_proxy_authenticate_clone  osip_www_authenticate_clone
 
 /**
  * Get value of the auth_type parameter from a Proxy-Authenticate element.
