@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -62,36 +62,45 @@ extern "C"
     int status_code;                  /**< Status Code (SIP answer only) */
     char *reason_phrase;              /**< Reason Phrase (SIP answer only) */
 
-    osip_list_t *accepts;             /**< Accept headers */
-    osip_list_t *accept_encodings;    /**< Accept-Encoding headers */
-    osip_list_t *accept_languages;    /**< Accept-Language headers */
-    osip_list_t *alert_infos;         /**< Alert-Info headers */
-    osip_list_t *allows;              /**< Allows headers */
-    osip_list_t *authentication_infos;/**< authentication_info headers */
-    osip_list_t *authorizations;      /**< Authorizations headers */
+#ifndef MINISIZE
+    osip_list_t accepts;             /**< Accept headers */
+    osip_list_t accept_encodings;    /**< Accept-Encoding headers */
+    osip_list_t accept_languages;    /**< Accept-Language headers */
+    osip_list_t alert_infos;         /**< Alert-Info headers */
+    osip_list_t allows;              /**< Allows headers */
+    osip_list_t authentication_infos;/**< authentication_info headers */
+#endif
+    osip_list_t authorizations;      /**< Authorizations headers */
     osip_call_id_t *call_id;          /**< Call-ID header */
-    osip_list_t *call_infos;          /**< Call-Infos header */
-    osip_list_t *contacts;            /**< Contacts headers */
-    osip_list_t *content_dispositions;/**< Content-Dispositions headers */
-    osip_list_t *content_encodings;   /**< Content-Encodings headers */
+#ifndef MINISIZE
+    osip_list_t call_infos;          /**< Call-Infos header */
+#endif
+    osip_list_t contacts;            /**< Contacts headers */
+#ifndef MINISIZE
+    osip_list_t content_encodings;   /**< Content-Encodings headers */
+#endif
     osip_content_length_t *content_length;   /**< Content-Length header */
     osip_content_type_t *content_type;       /**< Content-Type header */
     osip_cseq_t *cseq;                /**< CSeq header */
-    osip_list_t *error_infos;         /**< Error-Info headers */
+#ifndef MINISIZE
+    osip_list_t error_infos;         /**< Error-Info headers */
+#endif
     osip_from_t *from;                /**< From header */
     osip_mime_version_t *mime_version;/**< Mime-Version header */
-    osip_list_t *proxy_authenticates; /**< Proxy-Authenticate headers */
-    osip_list_t *proxy_authentication_infos; /**< P-Authentication-Info headers */
-    osip_list_t *proxy_authorizations;/**< Proxy-authorization headers */
-    osip_list_t *record_routes;       /**< Record-Route headers */
-    osip_list_t *routes;              /**< Route headers */
+    osip_list_t proxy_authenticates; /**< Proxy-Authenticate headers */
+#ifndef MINISIZE
+    osip_list_t proxy_authentication_infos; /**< P-Authentication-Info headers */
+#endif
+    osip_list_t proxy_authorizations;/**< Proxy-authorization headers */
+    osip_list_t record_routes;       /**< Record-Route headers */
+    osip_list_t routes;              /**< Route headers */
     osip_to_t *to;                    /**< To header */
-    osip_list_t *vias;                /**< Vias headers */
-    osip_list_t *www_authenticates;   /**< WWW-Authenticate headers */
+    osip_list_t vias;                /**< Vias headers */
+    osip_list_t www_authenticates;   /**< WWW-Authenticate headers */
 
-    osip_list_t *headers;             /**< Other headers */
+    osip_list_t headers;             /**< Other headers */
 
-    osip_list_t *bodies;              /**< List of attachements */
+    osip_list_t bodies;              /**< List of attachements */
 
     /*
        1: structure and buffer "message" are identical.
@@ -115,7 +124,7 @@ extern "C"
 /**
  * You can define the maximum length for a body inside a SIP message.
  */
-#define BODY_MESSAGE_MAX_SIZE  1000
+#define BODY_MESSAGE_MAX_SIZE  4000
 #endif
 
 /**
@@ -135,13 +144,31 @@ extern "C"
  * @param length The length of the buffer to parse.
  */
   int osip_message_parse (osip_message_t * sip, const char *buf, size_t length);
+/**
+ * Parse a message/sipfrag part and store it in an osip_message_t element.
+ * @param sip The resulting element.
+ * @param buf The buffer to parse.
+ * @param length The length of the buffer to parse.
+ */
+  int osip_message_parse_sipfrag (osip_message_t * sip, const char *buf,
+                                  size_t length);
 /**
  * Get a string representation of a osip_message_t element.
  * @param sip The element to work on.
  * @param dest new allocated buffer returned.
  * @param message_length The length of the returned buffer.
  */
-  int osip_message_to_str (osip_message_t * sip, char **dest, size_t *message_length);
+  int osip_message_to_str (osip_message_t * sip, char **dest,
+                           size_t * message_length);
+/**
+ * Get a string representation of a message/sipfrag part
+ * stored in an osip_message_t element.
+ * @param sip The element to work on.
+ * @param dest new allocated buffer returned.
+ * @param message_length The length of the returned buffer.
+ */
+  int osip_message_to_str_sipfrag (osip_message_t * sip, char **dest,
+                                   size_t * message_length);
 /**
  * Clone a osip_message_t element.
  * @param sip The element to clone.
@@ -384,7 +411,7 @@ extern "C"
  * @param GP The element to work on.
  * @param DEST The resulting new allocated buffer.
  */
-#define osip_generic_param_clone(GP,DEST)     osip_uri_param_clone(GP,DEST)
+#define osip_generic_param_clone      osip_uri_param_clone
 #ifndef DOXYGEN
 /*
  * Free a list of a generic parameter element.
@@ -413,26 +440,35 @@ extern "C"
  * @param name the token name to set.
  */
   void osip_generic_param_set_name (osip_generic_param_t * generic_param,
-				    char *name);
+                                    char *name);
 /**
  * Get the name of a generic parameter element.
  * @param generic_param The element to work on.
  */
-  char *osip_generic_param_get_name (const osip_generic_param_t *
-				     generic_param);
+  char *osip_generic_param_get_name (const osip_generic_param_t * generic_param);
 /**
  * Set the value of a generic parameter element.
  * @param generic_param The element to work on.
  * @param value the token name to set.
  */
   void osip_generic_param_set_value (osip_generic_param_t * generic_param,
-				     char *value);
+                                     char *value);
 /**
  * Get the value of a generic parameter element.
  * @param generic_param The element to work on.
  */
-  char *osip_generic_param_get_value (const osip_generic_param_t *
-				      generic_param);
+  char *osip_generic_param_get_value (const osip_generic_param_t * generic_param);
+
+
+/**
+ * Get the a known header from a list of known header.
+ * @param header_list The element to work on.
+ * @param pos The index of the element to get.
+ * @param dest A pointer on the header found.
+ */
+  int osip_message_get_knownheaderlist (osip_list_t *header_list,
+					int pos,
+					void **dest);
 
 /** @} */
 
