@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,8 @@
 #include "fsm.h"
 #include "xixt.h"
 
+#ifndef MINISIZE
+
 osip_statemachine_t *ict_fsm;
 
 osip_statemachine_t *
@@ -31,7 +33,6 @@ __ict_get_fsm ()
   return ict_fsm;
 }
 
-
 void
 __ict_unload_fsm ()
 {
@@ -48,7 +49,6 @@ __ict_unload_fsm ()
   osip_free (statemachine);
 }
 
-
 void
 __ict_load_fsm ()
 {
@@ -135,6 +135,84 @@ __ict_load_fsm ()
 
 }
 
+#else
+
+transition_t ict_transition[11] =
+  {
+    {
+      ICT_PRE_CALLING,
+      SND_REQINVITE,
+      (void (*)(void *, void *)) &ict_snd_invite,
+      &ict_transition[1], NULL
+    }
+    ,
+    {
+      ICT_CALLING,
+      TIMEOUT_A,
+      (void (*)(void *, void *)) &osip_ict_timeout_a_event,
+      &ict_transition[2], NULL
+    }
+    ,
+    {
+      ICT_CALLING,
+      TIMEOUT_B,
+      (void (*)(void *, void *)) &osip_ict_timeout_b_event,
+      &ict_transition[3], NULL
+    }
+    ,
+    { ICT_CALLING,
+      RCV_STATUS_1XX,
+      (void (*)(void *, void *)) &ict_rcv_1xx,
+      &ict_transition[4], NULL
+    }
+    ,
+    { ICT_CALLING,
+      RCV_STATUS_2XX,
+      (void (*)(void *, void *)) &ict_rcv_2xx,
+      &ict_transition[5], NULL
+    }
+    ,
+    { ICT_CALLING,
+      RCV_STATUS_3456XX,
+      (void (*)(void *, void *)) &ict_rcv_3456xx,
+      &ict_transition[6], NULL
+    }
+    ,
+    { ICT_PROCEEDING,
+      RCV_STATUS_1XX,
+      (void (*)(void *, void *)) &ict_rcv_1xx,
+      &ict_transition[7], NULL
+    }
+    ,
+    { ICT_PROCEEDING,
+      RCV_STATUS_2XX,
+      (void (*)(void *, void *)) &ict_rcv_2xx,
+      &ict_transition[8], NULL
+    }
+    ,
+    { ICT_PROCEEDING,
+      RCV_STATUS_3456XX,
+      (void (*)(void *, void *)) &ict_rcv_3456xx,
+      &ict_transition[9], NULL
+    }
+    ,
+    { ICT_COMPLETED,
+      RCV_STATUS_3456XX,
+      (void (*)(void *, void *)) &ict_retransmit_ack,
+      &ict_transition[10], NULL
+    }
+    ,
+    { ICT_COMPLETED,
+      TIMEOUT_D,
+      (void (*)(void *, void *)) &osip_ict_timeout_d_event,
+      NULL, NULL
+    }
+  };
+
+osip_statemachine_t ict_fsm = { ict_transition };
+
+#endif
+
 static void
 ict_handle_transport_error (osip_transaction_t * ict, int err)
 {
@@ -364,12 +442,21 @@ ict_rcv_3456xx (osip_transaction_t * ict, osip_event_t * evt)
                                         osip_strdup (route->url->host), port);
           } else
             {
-              int port = 5060;
-
-              if (ack->req_uri->port != NULL)
-                port = osip_atoi (ack->req_uri->port);
-              osip_ict_set_destination (ict->ict_context,
-                                        osip_strdup (ack->req_uri->host), port);
+	      int port = 5060;
+	      /* search for maddr parameter */
+	      osip_uri_param_t *maddr_param = NULL;
+	      
+	      port = 5060;
+	      if (ack->req_uri->port != NULL)
+		port = osip_atoi (ack->req_uri->port);
+	      
+	      osip_uri_uparam_get_byname (ack->req_uri, "maddr", &maddr_param);
+	      if (maddr_param!=NULL && maddr_param->gvalue!=NULL)
+		osip_ict_set_destination (ict->ict_context,
+					  osip_strdup (maddr_param->gvalue), port);
+	      else
+		osip_ict_set_destination (ict->ict_context,
+					  osip_strdup (ack->req_uri->host), port);
             }
         }
       i = osip->cb_send_message (ict, ack, ict->ict_context->destination,
@@ -391,32 +478,6 @@ ict_rcv_3456xx (osip_transaction_t * ict, osip_event_t * evt)
       __osip_message_callback (OSIP_ICT_ACK_SENT, ict, evt->sip);
     }
 
-  /* TEST ME:
-     sipevt = osip_fifo_tryget(ict->transactionff);
-     if (sipevt==NULL)
-     {}
-     else if (sipevt->sip==NULL)
-     osip_fifo_insert(ict->transactionff, sipevt);
-     else if (MSG_IS_RESPONSE(sipevt->sip))
-     {
-     if (sipevt->sip->status_code==evt->sip->status_code)
-     {
-     OSIP_TRACE (osip_trace
-     (__FILE__, __LINE__, OSIP_WARNING, NULL,
-     "discard this clone of late response... callid:%s\n",
-     evt->sip->call_id->number));
-     osip_message_free(sipevt->sip);
-     osip_free(sipevt);
-     }
-     else
-     {
-     osip_fifo_insert(ict->transactionff, sipevt);
-     }
-     }
-     else
-     osip_fifo_insert(ict->transactionff, sipevt);
-   */
-
   /* start timer D (length is set to MAX (64*DEFAULT_T1 or 32000) */
   osip_gettimeofday (&ict->ict_context->timer_d_start, NULL);
   add_gettimeofday (&ict->ict_context->timer_d_start,
