@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,8 @@
 
 #include "fsm.h"
 
+#ifndef MINISIZE
+
 osip_statemachine_t *nict_fsm;
 
 osip_statemachine_t *
@@ -150,6 +152,100 @@ __nict_load_fsm ()
 
 }
 
+#else
+
+transition_t nict_transition[12] =
+  {
+    {
+      NICT_PRE_TRYING,
+      SND_REQUEST,
+      (void (*)(void *, void *)) &nict_snd_request,
+      &nict_transition[1], NULL
+    }
+    ,
+    {
+      NICT_TRYING,
+      TIMEOUT_F,
+      (void (*)(void *, void *)) &osip_nict_timeout_f_event,
+      &nict_transition[2], NULL
+    }
+    ,
+    {
+      NICT_TRYING,
+      TIMEOUT_E,
+      (void (*)(void *, void *)) &osip_nict_timeout_e_event,
+      &nict_transition[3], NULL
+    }
+    ,
+    {
+      NICT_TRYING,
+      RCV_STATUS_1XX,
+      (void (*)(void *, void *)) &nict_rcv_1xx,
+      &nict_transition[4], NULL
+    }
+    ,
+    {
+      NICT_TRYING,
+      RCV_STATUS_2XX,
+      (void (*)(void *, void *)) &nict_rcv_23456xx,
+      &nict_transition[5], NULL
+    }
+    ,
+    {
+      NICT_TRYING,
+      RCV_STATUS_3456XX,
+      (void (*)(void *, void *)) &nict_rcv_23456xx,
+      &nict_transition[6], NULL
+    }
+    ,
+    {
+      NICT_PROCEEDING,
+      TIMEOUT_F,
+      (void (*)(void *, void *)) &osip_nict_timeout_f_event,
+      &nict_transition[7], NULL
+    }
+    ,
+    {
+      NICT_PROCEEDING,
+      TIMEOUT_E,
+      (void (*)(void *, void *)) &osip_nict_timeout_e_event,
+      &nict_transition[8], NULL
+    }
+    ,
+    {
+      NICT_PROCEEDING,
+      RCV_STATUS_1XX,
+      (void (*)(void *, void *)) &nict_rcv_1xx,
+      &nict_transition[9], NULL
+    }
+    ,
+    {
+      NICT_PROCEEDING,
+      RCV_STATUS_2XX,
+      (void (*)(void *, void *)) &nict_rcv_23456xx,
+      &nict_transition[10], NULL
+    }
+    ,
+    {
+      NICT_PROCEEDING,
+      RCV_STATUS_3456XX,
+      (void (*)(void *, void *)) &nict_rcv_23456xx,
+      &nict_transition[11], NULL
+    }
+    ,
+    {
+      NICT_COMPLETED,
+      TIMEOUT_K,
+      (void (*)(void *, void *)) &osip_nict_timeout_k_event,
+      NULL, NULL
+    }
+  };
+
+
+osip_statemachine_t nict_fsm = { nict_transition };
+
+#endif
+
 static void
 nict_handle_transport_error (osip_transaction_t * nict, int err)
 {
