@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -29,8 +29,7 @@ __osip_nist_init (osip_nist_t ** nist, osip_t * osip, osip_message_t * invite)
   int i;
 
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_INFO2, NULL,
-	       "allocating NIST context\n"));
+              (__FILE__, __LINE__, OSIP_INFO2, NULL, "allocating NIST context\n"));
 
   *nist = (osip_nist_t *) osip_malloc (sizeof (osip_nist_t));
   if (*nist == NULL)
@@ -41,7 +40,7 @@ __osip_nist_init (osip_nist_t ** nist, osip_t * osip, osip_message_t * invite)
     osip_via_t *via;
     char *proto;
 
-    i = osip_message_get_via (invite, 0, &via);	/* get top via */
+    i = osip_message_get_via (invite, 0, &via); /* get top via */
     if (i != 0)
       goto ii_error_1;
     proto = via_get_protocol (via);
@@ -49,16 +48,15 @@ __osip_nist_init (osip_nist_t ** nist, osip_t * osip, osip_message_t * invite)
       goto ii_error_1;
 
     if (osip_strcasecmp (proto, "TCP") != 0
-	&& osip_strcasecmp (proto, "TLS") !=0
-	&& osip_strcasecmp (proto, "SCTP") !=0)
+        && osip_strcasecmp (proto, "TLS") != 0
+        && osip_strcasecmp (proto, "SCTP") != 0)
       {
-	(*nist)->timer_j_length = 64 * DEFAULT_T1;
-	(*nist)->timer_j_start.tv_sec = -1;	/* not started */
-      }
-    else
-      {				/* reliable protocol is used: */
-	(*nist)->timer_j_length = 0;	/* MUST do the transition immediatly */
-	(*nist)->timer_j_start.tv_sec = -1;	/* not started */
+        (*nist)->timer_j_length = 64 * DEFAULT_T1;
+        (*nist)->timer_j_start.tv_sec = -1;     /* not started */
+    } else
+      {                         /* reliable protocol is used: */
+        (*nist)->timer_j_length = 0;    /* MUST do the transition immediatly */
+        (*nist)->timer_j_start.tv_sec = -1;     /* not started */
       }
   }
 
@@ -75,8 +73,7 @@ __osip_nist_free (osip_nist_t * nist)
   if (nist == NULL)
     return -1;
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_INFO2, NULL,
-	       "free nist ressource\n"));
+              (__FILE__, __LINE__, OSIP_INFO2, NULL, "free nist ressource\n"));
 
   osip_free (nist);
   return 0;
@@ -85,20 +82,11 @@ __osip_nist_free (osip_nist_t * nist)
 
 
 osip_event_t *
-__osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state, int transactionid)
+__osip_nist_need_timer_j_event (osip_nist_t * nist, state_t state,
+                                int transactionid)
 {
-  struct timeval now;
-  osip_gettimeofday (&now, NULL);
-
-  if (nist == NULL)
-    return NULL;
-  if (state == NIST_COMPLETED)
-    {
-      if (nist->timer_j_start.tv_sec == -1)
-	return NULL;
-      if (osip_timercmp (&now, &nist->timer_j_start, >))
-	return __osip_event_new (TIMEOUT_J, transactionid);
-    }
-  return NULL;
+  return __osip_transaction_need_timer_x_event(nist, &nist->timer_j_start,
+					       state == NIST_COMPLETED,
+					       transactionid,
+					       TIMEOUT_J);
 }
-
