@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,8 @@
 
 #include "fsm.h"
 
+#ifndef MINISIZE
+
 osip_statemachine_t *nist_fsm;
 
 osip_statemachine_t *
@@ -61,15 +63,6 @@ __nist_load_fsm ()
   transition->method = (void (*)(void *, void *)) &nist_rcv_request;
   ADD_ELEMENT (nist_fsm->transitions, transition);
 
-  /* This can be used to announce request but is useless, as
-     the transaction cannot send any response yet!
-     transition         = (transition_t *) osip_malloc(sizeof(transition_t));
-     transition->state  = NIST_TRYING;
-     transition->type   = RCV_REQUEST;
-     transition->method = (void(*)(void *,void *))&nist_rcv_request;
-     osip_list_add(nist_fsm->transitions,transition,-1);
-   */
-
   transition = (transition_t *) osip_malloc (sizeof (transition_t));
   transition->state = NIST_TRYING;
   transition->type = SND_STATUS_1XX;
@@ -126,6 +119,85 @@ __nist_load_fsm ()
 
 }
 
+#else
+
+transition_t nist_transition[10] =
+  {
+    {
+      NIST_PRE_TRYING,
+      RCV_REQUEST,
+      (void (*)(void *, void *)) &nist_rcv_request,
+      &nist_transition[1], NULL
+    }
+    ,
+    {
+      NIST_TRYING,
+      SND_STATUS_1XX,
+      (void (*)(void *, void *)) &nist_snd_1xx,
+      &nist_transition[2], NULL
+    }
+    ,
+    {
+      NIST_TRYING,
+      SND_STATUS_2XX,
+      (void (*)(void *, void *)) &nist_snd_23456xx,
+      &nist_transition[3], NULL
+    }
+    ,
+    {
+      NIST_TRYING,
+      SND_STATUS_3456XX,
+      (void (*)(void *, void *)) &nist_snd_23456xx,
+      &nist_transition[4], NULL
+    }
+    ,
+    {
+      NIST_PROCEEDING,
+      SND_STATUS_1XX,
+      (void (*)(void *, void *)) &nist_snd_1xx,
+      &nist_transition[5], NULL
+    }
+    ,
+    {
+      NIST_PROCEEDING,
+      SND_STATUS_2XX,
+      (void (*)(void *, void *)) &nist_snd_23456xx,
+      &nist_transition[6], NULL
+    }
+    ,
+    {
+      NIST_PROCEEDING,
+      SND_STATUS_3456XX,
+      (void (*)(void *, void *)) &nist_snd_23456xx,
+      &nist_transition[7], NULL
+    }
+    ,
+    {
+      NIST_PROCEEDING,
+      RCV_REQUEST,
+      (void (*)(void *, void *)) &nist_rcv_request,
+      &nist_transition[8], NULL
+    }
+    ,
+    {
+      NIST_COMPLETED,
+      TIMEOUT_J,
+      (void (*)(void *, void *)) &osip_nist_timeout_j_event,
+      &nist_transition[9], NULL
+    }
+    ,
+    {
+      NIST_COMPLETED,
+      RCV_REQUEST,
+      (void (*)(void *, void *)) &nist_rcv_request,
+      NULL, NULL
+    }
+  };
+
+osip_statemachine_t nist_fsm = { nist_transition };
+
+#endif
+
 static void
 nist_handle_transport_error (osip_transaction_t * nist, int err)
 {
@@ -139,7 +211,6 @@ void
 nist_rcv_request (osip_transaction_t * nist, osip_event_t * evt)
 {
   int i;
-  osip_t *osip = (osip_t *) nist->config;
 
   if (nist->state == NIST_PRE_TRYING)   /* announce new REQUEST */
     {
@@ -178,48 +249,7 @@ nist_rcv_request (osip_transaction_t * nist, osip_event_t * evt)
                                nist->orig_request);
       if (nist->last_response != NULL)  /* retransmit last response */
         {
-          osip_via_t *via;
-
-          via = (osip_via_t *) osip_list_get (&nist->last_response->vias, 0);
-          if (via)
-            {
-              char *host;
-              int port;
-              osip_generic_param_t *maddr;
-              osip_generic_param_t *received;
-              osip_generic_param_t *rport;
-
-              osip_via_param_get_byname (via, "maddr", &maddr);
-              osip_via_param_get_byname (via, "received", &received);
-              osip_via_param_get_byname (via, "rport", &rport);
-              /* 1: user should not use the provided information
-                 (host and port) if they are using a reliable
-                 transport. Instead, they should use the already
-                 open socket attached to this transaction. */
-              /* 2: check maddr and multicast usage */
-              if (maddr != NULL)
-                host = maddr->gvalue;
-              /* we should check if this is a multicast address and use
-                 set the "ttl" in this case. (this must be done in the
-                 UDP message (not at the SIP layer) */
-              else if (received != NULL)
-                host = received->gvalue;
-              else
-                host = via->host;
-
-              if (rport == NULL || rport->gvalue == NULL)
-                {
-                  if (via->port != NULL)
-                    port = osip_atoi (via->port);
-                  else
-                    port = 5060;
-              } else
-                port = osip_atoi (rport->gvalue);
-
-              i = osip->cb_send_message (nist, nist->last_response, host,
-                                         port, nist->out_socket);
-          } else
-            i = -1;
+	  i = __osip_transaction_snd_xxx(nist, nist->last_response);
           if (i != 0)
             {
               nist_handle_transport_error (nist, i);
@@ -250,8 +280,6 @@ void
 nist_snd_1xx (osip_transaction_t * nist, osip_event_t * evt)
 {
   int i;
-  osip_via_t *via;
-  osip_t *osip = (osip_t *) nist->config;
 
   if (nist->last_response != NULL)
     {
@@ -259,45 +287,7 @@ nist_snd_1xx (osip_transaction_t * nist, osip_event_t * evt)
     }
   nist->last_response = evt->sip;
 
-  via = (osip_via_t *) osip_list_get (&nist->last_response->vias, 0);
-  if (via)
-    {
-      char *host;
-      int port;
-      osip_generic_param_t *maddr;
-      osip_generic_param_t *received;
-      osip_generic_param_t *rport;
-
-      osip_via_param_get_byname (via, "maddr", &maddr);
-      osip_via_param_get_byname (via, "received", &received);
-      osip_via_param_get_byname (via, "rport", &rport);
-      /* 1: user should not use the provided information
-         (host and port) if they are using a reliable
-         transport. Instead, they should use the already
-         open socket attached to this transaction. */
-      /* 2: check maddr and multicast usage */
-      if (maddr != NULL)
-        host = maddr->gvalue;
-      /* we should check if this is a multicast address and use
-         set the "ttl" in this case. (this must be done in the
-         UDP message (not at the SIP layer) */
-      else if (received != NULL)
-        host = received->gvalue;
-      else
-        host = via->host;
-
-      if (rport == NULL || rport->gvalue == NULL)
-        {
-          if (via->port != NULL)
-            port = osip_atoi (via->port);
-          else
-            port = 5060;
-      } else
-        port = osip_atoi (rport->gvalue);
-      i = osip->cb_send_message (nist, nist->last_response, host,
-                                 port, nist->out_socket);
-  } else
-    i = -1;
+  i = __osip_transaction_snd_xxx(nist, nist->last_response);
   if (i != 0)
     {
       nist_handle_transport_error (nist, i);
@@ -312,8 +302,6 @@ void
 nist_snd_23456xx (osip_transaction_t * nist, osip_event_t * evt)
 {
   int i;
-  osip_via_t *via;
-  osip_t *osip = (osip_t *) nist->config;
 
   if (nist->last_response != NULL)
     {
@@ -321,45 +309,7 @@ nist_snd_23456xx (osip_transaction_t * nist, osip_event_t * evt)
     }
   nist->last_response = evt->sip;
 
-  via = (osip_via_t *) osip_list_get (&nist->last_response->vias, 0);
-  if (via)
-    {
-      char *host;
-      int port;
-      osip_generic_param_t *maddr;
-      osip_generic_param_t *received;
-      osip_generic_param_t *rport;
-
-      osip_via_param_get_byname (via, "maddr", &maddr);
-      osip_via_param_get_byname (via, "received", &received);
-      osip_via_param_get_byname (via, "rport", &rport);
-      /* 1: user should not use the provided information
-         (host and port) if they are using a reliable
-         transport. Instead, they should use the already
-         open socket attached to this transaction. */
-      /* 2: check maddr and multicast usage */
-      if (maddr != NULL)
-        host = maddr->gvalue;
-      /* we should check if this is a multicast address and use
-         set the "ttl" in this case. (this must be done in the
-         UDP message (not at the SIP layer) */
-      else if (received != NULL)
-        host = received->gvalue;
-      else
-        host = via->host;
-
-      if (rport == NULL || rport->gvalue == NULL)
-        {
-          if (via->port != NULL)
-            port = osip_atoi (via->port);
-          else
-            port = 5060;
-      } else
-        port = osip_atoi (rport->gvalue);
-      i = osip->cb_send_message (nist, nist->last_response, host,
-                                 port, nist->out_socket);
-  } else
-    i = -1;
+  i = __osip_transaction_snd_xxx(nist, nist->last_response);
   if (i != 0)
     {
       nist_handle_transport_error (nist, i);
