@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -51,7 +51,32 @@ min_timercmp (struct timeval *tv1, struct timeval *tv2)
     }
 }
 
-#if !defined(__PALMOS__) && (defined(WIN32) || defined(_WIN32_WCE))
+#if !defined(__PALMOS__) && defined(_WIN32_WCE)
+
+#include <time.h>
+
+int
+osip_gettimeofday (struct timeval *tp, void *tz)
+{
+  DWORD timemillis = GetTickCount();
+  tp->tv_sec  = timemillis/1000;
+  tp->tv_usec = (timemillis - (tp->tv_sec*1000)) * 1000;
+  return 0;
+}
+
+time_t
+time (time_t *t)
+{
+    DWORD timemillis = GetTickCount();
+	if (timemillis>0)
+	{
+		if (t!=NULL)
+			*t = timemillis/1000;
+	}
+	return timemillis/1000;
+}
+
+#elif !defined(__PALMOS__) && defined(WIN32)
 
 #include <time.h>
 #include <sys/timeb.h>
@@ -68,3 +93,21 @@ osip_gettimeofday (struct timeval *tp, void *tz)
 }
 
 #endif
+
+#if defined(__arc__)
+
+time_t
+time (time_t *t)
+{
+  struct timeval now;
+
+  osip_gettimeofday (&now, NULL);
+  
+  if (t!=NULL)
+    {
+      *t = now.tv_sec;
+    }
+  return now.tv_sec;
+}
+
+#endif
