@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,8 @@
 #include <osipparser2/osip_parser.h>
 #include "parser.h"
 
+#ifndef MINISIZE
+
 int
 osip_message_set_alert_info (osip_message_t * sip, const char *hvalue)
 {
@@ -44,7 +46,7 @@ osip_message_set_alert_info (osip_message_t * sip, const char *hvalue)
       return -1;
     }
   sip->message_property = 2;
-  osip_list_add (sip->alert_infos, alert_info, -1);
+  osip_list_add (&sip->alert_infos, alert_info, -1);
   return 0;
 }
 
@@ -55,9 +57,11 @@ osip_message_get_alert_info (const osip_message_t * sip, int pos,
   osip_alert_info_t *alert_info;
 
   *dest = NULL;
-  if (osip_list_size (sip->alert_infos) <= pos)
+  if (osip_list_size (&sip->alert_infos) <= pos)
     return -1;                  /* does not exist */
-  alert_info = (osip_alert_info_t *) osip_list_get (sip->alert_infos, pos);
+  alert_info = (osip_alert_info_t *) osip_list_get (&sip->alert_infos, pos);
   *dest = alert_info;
   return pos;
 }
+
+#endif
