@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -81,6 +81,7 @@ osip_content_length_parse (osip_content_length_t * content_length,
   return 0;
 }
 
+#ifndef MINISIZE
 /* returns the content_length header.            */
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
@@ -89,6 +90,7 @@ osip_message_get_content_length (const osip_message_t * sip)
 {
   return sip->content_length;
 }
+#endif
 
 /* returns the content_length header as a string.          */
 /* INPUT : osip_content_length_t *content_length | content_length header.  */
