@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -32,22 +32,36 @@ osip_list_init (osip_list_t * li)
   return 0;                     /* ok */
 }
 
+int osip_list_clone (const osip_list_t * src, osip_list_t * dst, int *(*clone_func) (void *, void *))
+{
+    void *data;
+    void *data2;
+    int pos=0;
+    while (!osip_list_eol (src, pos))
+      {
+        data = osip_list_get (src, pos);
+        if (clone_func (data, &data2)!=0)
+	  return -1;
+        osip_list_add (dst, data2, -1);
+        pos++;
+      }
+    return 0;
+}
+
 void
 osip_list_special_free (osip_list_t * li, void *(*free_func) (void *))
 {
-  int pos = 0;
   void *element;
 
   if (li == NULL)
     return;
-  while (!osip_list_eol (li, pos))
+  while (!osip_list_eol (li, 0))
     {
-      element = (void *) osip_list_get (li, pos);
-      osip_list_remove (li, pos);
+      element = (void *) osip_list_get (li, 0);
+      osip_list_remove (li, 0);
       if (free_func != NULL)
         free_func (element);
     }
-  osip_free (li);
 }
 
 void
@@ -64,7 +78,6 @@ osip_list_ofchar_free (osip_list_t * li)
       osip_list_remove (li, pos);
       osip_free (chain);
     }
-  osip_free (li);
 }
 
 int
