@@ -56,11 +56,11 @@ documentation and/or software.
 #define S43 15
 #define S44 21
 
-static void MD5Transform PROTO_LIST ((UINT4[4], unsigned char[64]));
-static void Encode PROTO_LIST ((unsigned char *, UINT4 *, unsigned int));
-static void Decode PROTO_LIST ((UINT4 *, unsigned char *, unsigned int));
-static void MD5_memcpy PROTO_LIST ((POINTER, POINTER, unsigned int));
-static void MD5_memset PROTO_LIST ((POINTER, int, unsigned int));
+static void osip_MD5Transform PROTO_LIST ((UINT4[4], unsigned char[64]));
+static void osip_Encode PROTO_LIST ((unsigned char *, UINT4 *, unsigned int));
+static void osip_Decode PROTO_LIST ((UINT4 *, unsigned char *, unsigned int));
+static void osip_MD5_memcpy PROTO_LIST ((POINTER, POINTER, unsigned int));
+static void osip_MD5_memset PROTO_LIST ((POINTER, int, unsigned int));
 
 static unsigned char PADDING[64] = {
   0x80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -106,7 +106,7 @@ Rotation is separate from addition to prevent recomputation.
 /* MD5 initialization. Begins an MD5 operation, writing a new context.
  */
 void
-MD5Init (MD5_CTX * context      /* context */
+osip_MD5Init (osip_MD5_CTX * context      /* context */
   )
 {
   context->count[0] = context->count[1] = 0;
@@ -123,7 +123,7 @@ MD5Init (MD5_CTX * context      /* context */
   context.
  */
 void
-MD5Update (MD5_CTX * context,   /* context */
+osip_MD5Update (osip_MD5_CTX * context,   /* context */
            unsigned char *input,        /* input block */
            unsigned int inputLen        /* length of input block */
   )
@@ -144,18 +144,18 @@ MD5Update (MD5_CTX * context,   /* context */
    */
   if (inputLen >= partLen)
     {
-      MD5_memcpy ((POINTER) & context->buffer[index], (POINTER) input, partLen);
-      MD5Transform (context->state, context->buffer);
+      osip_MD5_memcpy ((POINTER) & context->buffer[index], (POINTER) input, partLen);
+      osip_MD5Transform (context->state, context->buffer);
 
       for (i = partLen; i + 63 < inputLen; i += 64)
-        MD5Transform (context->state, &input[i]);
+        osip_MD5Transform (context->state, &input[i]);
 
       index = 0;
   } else
     i = 0;
 
   /* Buffer remaining input */
-  MD5_memcpy
+  osip_MD5_memcpy
     ((POINTER) & context->buffer[index], (POINTER) & input[i], inputLen - i);
 }
 
@@ -163,41 +163,41 @@ MD5Update (MD5_CTX * context,   /* context */
   the message digest and zeroizing the context.
  */
 void
-MD5Final (unsigned char digest[16],     /* message digest */
-          MD5_CTX * context     /* context */
+osip_MD5Final (unsigned char digest[16],     /* message digest */
+          osip_MD5_CTX * context     /* context */
   )
 {
   unsigned char bits[8];
   unsigned int index, padLen;
 
   /* Save number of bits */
-  Encode (bits, context->count, 8);
+  osip_Encode (bits, context->count, 8);
 
   /* Pad out to 56 mod 64.
    */
   index = (unsigned int) ((context->count[0] >> 3) & 0x3f);
   padLen = (index < 56) ? (56 - index) : (120 - index);
-  MD5Update (context, PADDING, padLen);
+  osip_MD5Update (context, PADDING, padLen);
 
   /* Append length (before padding) */
-  MD5Update (context, bits, 8);
+  osip_MD5Update (context, bits, 8);
 
   /* Store state in digest */
-  Encode (digest, context->state, 16);
+  osip_Encode (digest, context->state, 16);
 
   /* Zeroize sensitive information.
    */
-  MD5_memset ((POINTER) context, 0, sizeof (*context));
+  osip_MD5_memset ((POINTER) context, 0, sizeof (*context));
 }
 
 /* MD5 basic transformation. Transforms state based on block.
  */
 static void
-MD5Transform (UINT4 state[4], unsigned char block[64])
+osip_MD5Transform (UINT4 state[4], unsigned char block[64])
 {
   UINT4 a = state[0], b = state[1], c = state[2], d = state[3], x[16];
 
-  Decode (x, block, 64);
+  osip_Decode (x, block, 64);
 
   /* Round 1 */
   FF (a, b, c, d, x[0], S11, 0xd76aa478);       /* 1 */
@@ -278,14 +278,14 @@ MD5Transform (UINT4 state[4], unsigned char block[64])
 
   /* Zeroize sensitive information.
    */
-  MD5_memset ((POINTER) x, 0, sizeof (x));
+  osip_MD5_memset ((POINTER) x, 0, sizeof (x));
 }
 
 /* Encodes input (UINT4) into output (unsigned char). Assumes len is
   a multiple of 4.
  */
 static void
-Encode (unsigned char *output, UINT4 * input, unsigned int len)
+osip_Encode (unsigned char *output, UINT4 * input, unsigned int len)
 {
   unsigned int i, j;
 
@@ -302,7 +302,7 @@ Encode (unsigned char *output, UINT4 * input, unsigned int len)
   a multiple of 4.
  */
 static void
-Decode (UINT4 * output, unsigned char *input, unsigned int len)
+osip_Decode (UINT4 * output, unsigned char *input, unsigned int len)
 {
   unsigned int i, j;
 
@@ -315,7 +315,7 @@ Decode (UINT4 * output, unsigned char *input, unsigned int len)
  */
 
 static void
-MD5_memcpy (POINTER output, POINTER input, unsigned int len)
+osip_MD5_memcpy (POINTER output, POINTER input, unsigned int len)
 {
   unsigned int i;
 
@@ -326,7 +326,7 @@ MD5_memcpy (POINTER output, POINTER input, unsigned int len)
 /* Note: Replace "for loop" with standard memset if possible.
  */
 static void
-MD5_memset (POINTER output, int value, unsigned int len)
+osip_MD5_memset (POINTER output, int value, unsigned int len)
 {
   unsigned int i;
 
