@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -48,12 +48,12 @@ osip_message_set_proxy_authenticate (osip_message_t * sip, const char *hvalue)
       return -1;
     }
   sip->message_property = 2;
-  osip_list_add (sip->proxy_authenticates, proxy_authenticate, -1);
+  osip_list_add (&sip->proxy_authenticates, proxy_authenticate, -1);
   return 0;
 }
 
 
-
+#ifndef MINISIZE
 /* returns the proxy_authenticate header.            */
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
@@ -64,12 +64,13 @@ osip_message_get_proxy_authenticate (const osip_message_t * sip, int pos,
   osip_proxy_authenticate_t *proxy_authenticate;
 
   *dest = NULL;
-  if (osip_list_size (sip->proxy_authenticates) <= pos)
+  if (osip_list_size (&sip->proxy_authenticates) <= pos)
     return -1;                  /* does not exist */
 
   proxy_authenticate = (osip_proxy_authenticate_t *)
-    osip_list_get (sip->proxy_authenticates, pos);
+    osip_list_get (&sip->proxy_authenticates, pos);
 
   *dest = proxy_authenticate;
   return pos;
 }
+#endif
