@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,8 @@
 #include <osipparser2/osip_message.h>
 #include <osipparser2/osip_parser.h>
 
+#ifndef MINISIZE
+
 /* fills the proxy-authentication_info header of message.               */
 /* INPUT :  char *hvalue | value of header.   */
 /* OUTPUT: osip_message_t *sip | structure to save results. */
@@ -50,7 +52,7 @@ osip_message_set_proxy_authentication_info (osip_message_t * sip,
     }
   sip->message_property = 2;
 
-  osip_list_add (sip->proxy_authentication_infos, proxy_authentication_info, -1);
+  osip_list_add (&sip->proxy_authentication_infos, proxy_authentication_info, -1);
   return 0;
 }
 
@@ -68,12 +70,14 @@ osip_message_get_proxy_authentication_info (const osip_message_t * sip,
   osip_proxy_authentication_info_t *proxy_authentication_info;
 
   *dest = NULL;
-  if (osip_list_size (sip->proxy_authentication_infos) <= pos)
+  if (osip_list_size (&sip->proxy_authentication_infos) <= pos)
     return -1;                  /* does not exist */
 
   proxy_authentication_info = (osip_proxy_authentication_info_t *)
-    osip_list_get (sip->proxy_authentication_infos, pos);
+    osip_list_get (&sip->proxy_authentication_infos, pos);
 
   *dest = proxy_authentication_info;
   return pos;
 }
+
+#endif
