@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -24,11 +24,13 @@
 #include <osipparser2/osip_message.h>
 #include <osipparser2/osip_parser.h>
 
+#ifndef MINISIZE
 int
 osip_route_init (osip_route_t ** route)
 {
   return osip_from_init ((osip_from_t **) route);
 }
+#endif
 
 /* adds the route header to message.         */
 /* INPUT : const char *hvalue | value of header.    */
@@ -57,10 +59,11 @@ osip_message_set_route (osip_message_t * sip, const char *hvalue)
       return -1;
     }
   sip->message_property = 2;
-  osip_list_add (sip->routes, route, -1);
+  osip_list_add (&sip->routes, route, -1);
   return 0;
 }
 
+#ifndef MINISIZE
 /* returns the route header.    */
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
@@ -70,13 +73,15 @@ osip_message_get_route (const osip_message_t * sip, int pos, osip_route_t ** des
   osip_route_t *route;
 
   *dest = NULL;
-  if (osip_list_size (sip->routes) <= pos)
+  if (osip_list_size (&sip->routes) <= pos)
     return -1;                  /* does not exist */
-  route = (osip_route_t *) osip_list_get (sip->routes, pos);
+  route = (osip_route_t *) osip_list_get (&sip->routes, pos);
   *dest = route;
   return pos;
 }
+#endif
 
+#ifndef MINISIZE
 int
 osip_route_parse (osip_route_t * route, const char *hvalue)
 {
@@ -101,3 +106,4 @@ osip_route_free (osip_route_t * route)
 {
   osip_from_free ((osip_from_t *) route);
 }
+#endif
